==> glest_3.0.0.orig.tar.gz: glest-source-3.0.0/shared_lib/include/util/properties.h <==
// ==============================================================
//	This file is part of Glest Shared Library (www.glest.org)
//
//	Copyright (C) 2001-2008 Martio Figueroa
//
//	You can redistribute this code and/or modify it under 
//	the terms of the GNU General Public License as published 
//	by the Free Software Foundation; either version 2 of the 
//	License, or (at your option) any later version
// ==============================================================

#ifndef _SHARED_UTIL_PROPERTIES_H_
#define _SHARED_UTIL_PROPERTIES_H_

#include <string>
#include <map>

using std::map;
using std::string;
using std::pair;

namespace Shared{ namespace Util{

// =====================================================
//	class Properties
//
///	ini-like file loader
// =====================================================

class Properties{
private:
	static const int maxLine= 256;

private:	
	typedef pair<string, string> PropertiesPair;
	typedef map<string, string> PropertiesMap;

private:
	PropertiesMap properties;
	string path;

public:
	void load(const string &path);
	void save(const string &path);

	bool getBool(const string &key) const;
	int getInt(const string &key) const;
	int getInt(const string &key, int min, int max) const;
	float getFloat(const string &key) const;
	float getFloat(const string &key, float min, float max) const;
	const string &getString(const string &key) const;

	void setInt(const string &key, int value);
	void setBool(const string &key, bool value);
	void setFloat(const string &key, float value);
	void setString(const string &key, const string &value);

	string toString();
};

}}//end namespace

#endif

==> glest_3.1.2.orig.tar.gz: glest-source-3.1.2/shared_lib/include/util/properties.h <==
// ==============================================================
//	This file is part of Glest Shared Library (www.glest.org)
//
//	Copyright (C) 2001-2008 Martio Figueroa
//
//	You can redistribute this code and/or modify it under 
//	the terms of the GNU General Public License as published 
//	by the Free Software Foundation; either version 2 of the 
//	License, or (at your option) any later version
// ==============================================================

#ifndef _SHARED_UTIL_PROPERTIES_H_
#define _SHARED_UTIL_PROPERTIES_H_

#include <string>
#include <map>
#include <vector>

using std::map;
using std::vector;
using std::string;
using std::pair;

namespace Shared{ namespace Util{

// =====================================================
//	class Properties
//
///	ini-like file loader
// =====================================================

class Properties{
private:
	static const int maxLine= 256;

public:	
	typedef pair<string, string> PropertyPair;
	typedef map<string, string> PropertyMap;
	typedef vector<PropertyPair> PropertyVector;
	
private:
	PropertyVector propertyVector;
	PropertyMap propertyMap;
	string path;

public:
	void load(const string &path);
	void save(const string &path);

	int getPropertyCount()	{return propertyVector.size();}
	string getKey(int i)	{return propertyVector[i].first;}
	string getString(int i)	{return propertyVector[i].second;}

	bool getBool(const string &key) const;
	int getInt(const string &key) const;
	int getInt(const string &key, int min, int max) const;
	float getFloat(const string &key) const;
	float getFloat(const string &key, float min, float max) const;
	const string &getString(const string &key) const;

	void setInt(const string &key, int value);
	void setBool(const string &key, bool value);
	void setFloat(const string &key, float value);
	void setString(const string &key, const string &value);

	string toString();


};

}}//end namespace

#endif
